@@ -1,4 +1,4 @@
-# test that nestedLogit()/predict.nested() correctly compute fitted probabilities
+# test that nestedLogit()/predict.nestedLogit() correctly compute fitted probabilities
 
 m2 <- nestedLogit(degree ~ parentdeg + year, 
                   continuationLogits(c("l.t.highschool",  "highschool", 
@@ -8,7 +8,8 @@ m2 <- nestedLogit(degree ~ parentdeg + year,
 new <- expand.grid(parentdeg=c("l.t.highschool",  "highschool", 
                                "college", "graduate"),
                    year=1972:2016)
-pred.GSS <- predict(m2, new)
+pred.GSS <- as.matrix(predict(m2, new)$p)
+
 p.m2.1 <- predict(models(m2, 1), newdata=new, type="response")
 p.m2.2 <- predict(models(m2, 2), newdata=new, type="response")
 p.m2.3 <- predict(models(m2, 3), newdata=new, type="response")
@@ -25,6 +26,6 @@ test_that("fitted probabilities computed correctly, test 3", {
   expect_equal(p.m2.1*p.m2.2*(1 - p.m2.3), pred.GSS[, "college"])
 })
 
-test_that("fitted probabilities computed correctly, test 1", {
+test_that("fitted probabilities computed correctly, test 4", {
   expect_equal(p.m2.1*p.m2.2*p.m2.3, pred.GSS[, "graduate"])
 })
